#/bin/bash
# Updates HomeControl
VERSIONURL=http://server47.de/homecontrol/interface.php?request=showAvailableVersion
CHECKSUMURL=http://server47.de/homecontrol/interface.php?request=checksum
ZIPURL=http://server47.de/homecontrol/download/homecontrol.tar.gz

HCFOLDER=/home/pi/HomeControl
TMPFILE=/tmp/homecontrolversion.txt
TMPCHK=/tmp/homecontrolchecksum.txt
wget "$VERSIONURL" -O "$TMPFILE"
AVAILABLEVERSION=$(cat "$TMPFILE")
INSTALLEDVERSION=$(cat version.txt)
LOCALARCHIVE=/home/pi/homecontrol.tar.gz
OLDFILE=HomeControl.jar.bak
NEWFILE=HomeControl.jar

echo "============================="
echo "Available version: $AVAILABLEVERSION"
echo "Installed version: $INSTALLEDVERSION"
echo "============================="

if [ $AVAILABLEVERSION -gt $INSTALLEDVERSION ]
then
	echo "Update available"
	rm "$TMPFILE"

	echo "Downloading newest version..."
	wget "$ZIPURL" -O "$LOCALARCHIVE"

	if [ "$?" -eq "0" ]
	then		
		CHECKSUMLOCAL=$(md5sum "$LOCALARCHIVE" |awk '{print $1}')
		wget "$CHECKSUMURL" -O "$TMPCHK"
		NEWCHECKSUMFROMSERVER=$(cat "$TMPCHK")
		rm "$TMPCHK"

		echo "Checking checksums..."
		echo "============================="
		echo "Remote checksum: $CHECKSUMLOCAL"
		echo "Local checksum:  $NEWCHECKSUMFROMSERVER"
		echo "============================="

		if [ "$CHECKSUMLOCAL" = "$NEWCHECKSUMFROMSERVER" ]
		then
			echo "Checksums match!"

			# Stop daemon if running
			echo "Stopping daemon if running..."
			sudo service homecontrol stop

			if [ "$?" = "0" ]
			then
				mv "$HCFOLDER"/HomeControl.jar "$HCFOLDER"/"$OLDFILE"
			else
				echo "Error stopping daemon."
				exit 5
			fi

			if [ "$?" -eq "0" ]
			then
				# Unpack downloaded file
				echo "Unpacking archive..."
				tar xzvf "$LOCALARCHIVE" -C /home/pi
				
				if [ "$?" -eq "0" ]
				then
					cd "$HCFOLDER"
					echo "Updating database..."

					java -jar HomeControl.jar -updateDatabase

					if [ "$?" -eq "0" ]
					then
						echo "Database update complete."

						echo "Starting daemon..."

						sudo service homecontrol start
						
						if [ "$?" -eq "0" ]
						then
							echo "==================================================="
							echo "           Update finished successfully!"
							echo "==================================================="
						else
							echo "================================================================"
							echo "Daemon could not be started, but update should be successfull."
							echo "================================================================"
						fi
					else
						echo "Error updating database."
					fi
				else
					echo "Rolling back..."

					mv "$HCFOLDER"/"$OLDFILE" "$HCFOLDER"/"$NEWFILE"

					if [ "$?" -eq "0" ]
					then
						echo "Error unpacking new archive. The old version has been restored."
					else
						echo "Error rolling back old version."
					fi
				fi
			else
				echo "Error stopping daemon"
			fi
		else
			echo "Wrong checksum! Try to restart script."
		fi
	else
		echo "Error downloading package from $ZIPURL"
	fi

	exit 1
else
	echo "No update available. Latest version already installed."
	exit 0
fi